<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\EmpresaFormRequest;
use Illuminate\Support\Facades\Auth;
use App\Empresa;
use App\User;
use App\BranchOffice;
use App\Schedule;
use Illuminate\Support\Facades\Redirect;

class EmpresaController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index(Request $request)
    {

        if (auth()->user()->TipoUsuario == "PERSONAL") {
            Auth::logout();
            return redirect('/')
                ->with('flash', 'Usted no tiene privilegios para ingresar en la ruta solicitada.');
        }
        if ($request) {
            $query = trim($request->get('searchText'));


            $empresa = Empresa::Where('nomEmpresa', 'LIKE', '%' . $query . '%')->Where('idEmpresa', '!=', 1)
                ->paginate(10);

            return view('control.empresas.index', ["empresa" => $empresa, "searchText" => $query]);
        }
    }

    public function store(EmpresaFormRequest $request)
    {
        $diasLaborados = "";
        if (!empty($request->get('diasLaborados'))) {
            foreach ($request->get('diasLaborados') as $d) {
                $diasLaborados .= '_' . $d;
            }
            $diasLaborados = substr($diasLaborados, 1, strlen($diasLaborados));
        }
        $empresa = new Empresa();
        $empresa->nomEmpresa = $request->get('nomEmpresa');
        $empresa->rutEmpresa = $request->get('rutEmpresa');
        $empresa->Direccion = $request->get('Direccion');
        $empresa->estadoEmpresa = 'OPERATIVO';
        if ($request->hasFile('Logo')) {
            $file = $request->file('Logo');
            $file->move(public_path() . '/logo', $file->getClientOriginalName());
            $empresa->Logo = $file->getClientOriginalName();
        }
        $empresa->AperturaSistema = $request->get('AperturaSistema');
        $empresa->diasHabilitados = $diasLaborados;
        $empresa->save();
        // Creamos un horario para los administradores de esta empresa (Registro Auxiliar)
        $schedule = new Schedule();
        $schedule->name = 'solo_admin';
        $schedule->checkinTime = '00:00:00';
        $schedule->departureTime = '00:00:00';
        $schedule->idEmpresa = $empresa->idEmpresa;
        $schedule->save();
        // Creamos un sucursal para los administradores de esta empresa (Registro Auxiliar)
        $branch_office = new BranchOffice();
        $branch_office->name = 'solo_admin';
        $branch_office->latitude = '0';
        $branch_office->longitude = '0';
        $branch_office->radius = 0;
        $branch_office->idEmpresa = $empresa->idEmpresa;
        $branch_office->save();

        return Redirect::to('control/empresas')->with(['success' =>  $empresa->nomEmpresa . ' agregado, correctamente!.']);
    }

    public function edit($id)
    {
        return view("control.empresas.edit", ["empresa" => Empresa::findOrFail($id)]);
    }

    public function update(EmpresaFormRequest $request, $id)
    {
        $diasLaborados = "";
        if (!empty($request->get('diasLaborados'))) {
            foreach ($request->get('diasLaborados') as $d) {
                $diasLaborados .= '_' . $d;
            }
            $diasLaborados = substr($diasLaborados, 1, strlen($diasLaborados));
        }
        $empresa = Empresa::findOrFail($id);
        $empresa->nomEmpresa = $request->get('nomEmpresa');
        $empresa->rutEmpresa = $request->get('rutEmpresa');
        $empresa->Direccion = $request->get('Direccion');

        if ($request->hasFile('Logo')) {
            $file = $request->file('Logo');
            $file->move(public_path() . '/logo', $file->getClientOriginalName());
            $empresa->Logo = $file->getClientOriginalName();
        }
        $empresa->AperturaSistema = $request->get('AperturaSistema');
        $empresa->diasHabilitados = $diasLaborados;
        $empresa->update();
        return Redirect::to('control/empresas')->with(['success' =>  $empresa->nomEmpresa . ' modificado, correctamente!.']);
    }


    public function destroy(Request $request, $id)
    {
        try {
            if ($request->ajax()) {

                $docu   = Empresa::findOrFail($id);
                $branch_office = DB::table('branch_office')->where('idEmpresa', $docu->idEmpresa)->delete();
                $schedule = DB::table('schedule')->where('idEmpresa', $docu->idEmpresa)->delete();

                if ($docu->delete()) {
                    return response()->json([
                        'success' => true,
                        'message' => '¡Satisfactorio!, Registro eliminado con éxito.',
                    ]);
                } else {
                    return response()->json([
                        'success' => false,
                        'message' => '¡Error!, No se pudo eliminar.',
                    ]);
                }
            }
        } catch (\Exception $e) {
            if ($request->ajax()) {
                return response()->json([
                    'success' => false,
                    'message' => '¡Error!, Este registro tiene enlazado uno o mas registros.',
                ]);
            }
        }
    }
    public function show($id)
    {
        $n_id = substr($id, 1);

        $vEmpresa=Empresa::findOrfail($n_id);
        if (isset($vEmpresa->estadoEmpresa)){
            if($vEmpresa->estadoEmpresa=='OPERATIVO'){
                $estado = "NO OPERATIVO";
            }else{
                $estado = "OPERATIVO";
            }
        }

        $empresa=Empresa::findOrFail($n_id);
        $empresa->estadoEmpresa=$estado;
        $empresa->update();
        return Redirect::to('control/empresas')->with(['success' => 'El estado de ' . $empresa->nomEmpresa . ' fué modificado.']);
    }
    public static function validation_destroy($id)
    {
        $c_BranchOffice = DB::table('usuario as u')->join('branch_office as b', 'u.idBranch_office', 'b.id')->Where('b.idEmpresa', $id)->get();
        $c_Schedule = DB::table('usuario as u')->join('schedule as s', 'u.IdSchedule', 's.id')->where('s.idEmpresa', $id)->get();

        return count($c_BranchOffice) == 0  && count($c_Schedule) == 0 ? true : false;
    }
}
