<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\UsuarioFormRequest;
use App\User;
use App\BranchOffice;
use App\Empresa;
use App\Schedule;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;

class Usuario2Controller extends Controller
{
    public function __construct(){
        $this->middleware('auth');
    }
    public function index(Request $request)
    {

        if (auth()->user()->TipoUsuario !="SUPER_ADMIN"){
            Auth::logout();
            return redirect('/')
            ->with('flash','Usted no tiene privilegios para ingresar en la ruta solicitada.');
        }
        if ($request) {
            $query=trim($request->get('searchText'));

            $usuario = DB::table('usuario as u')
            ->join('branch_office as b', 'u.idBranch_office', 'b.id') // solo enlace para saber de que empresa es
            ->join('empresa as e', 'b.idEmpresa', 'e.idEmpresa')
            ->select('u.IdUsuario', 'Nombres', 'NumDocumento', 'nomEmpresa',
            'u.Direccion', 'TelefCel', 'Correo', 'foto', 'Estado','TipoUsuario', 'estadoEmpresa')
            ->where('TipoUsuario', 'ADMINISTRADOR')
            ->where(function ($q)  use ($query) {
                $q->orWhere('Nombres', 'LIKE' , '%' . $query . '%')
                ->orWhere('NumDocumento', 'LIKE' , '%' . $query . '%')
                ->orWhere('nomEmpresa', 'LIKE' , '%' . $query . '%')
                ->orWhere('Estado', 'LIKE' , '%' . $query . '%');
            })
            ->orderByDesc('e.idEmpresa')
            ->orderByDesc('u.IdUsuario')
            ->paginate(7);

            $empresa = Empresa::Where('idEmpresa', '!=', 1)->get();

            return view('acceso.usuario2.index',["usuario"=>$usuario, "empresa"=>$empresa, "searchText"=>$query]);
        }

    }

    public function store(UsuarioFormRequest $request)
    {

        $branchOffice = DB::table('branch_office')->where('idEmpresa', $request->get('empresa'))
            ->where('name', 'solo_admin')
            ->first();
        $schedule = DB::table('schedule')->where('idEmpresa', $request->get('empresa'))
            ->where('name', 'solo_admin')
            ->first();

        $usuario = new User;
        $usuario->Nombres=$request->get('Nombres');
        $usuario->NumDocumento=$request->get('NumDocumento');
        $usuario->Direccion=$request->get('Direccion');
        $usuario->TelefCel=$request->get('Telefono');
        $usuario->Correo=$request->get('correo');
        $usuario->password = bcrypt($request->get('NumDocumento'));
        $usuario->Estado = "ACTIVO";
        $usuario->TipoUsuario = 'ADMINISTRADOR';
        if($request->hasFile('foto')){
            $file = $request->file('foto');
            $file->move(public_path().'/Imagen',$file->getClientOriginalName());
            $usuario -> foto=$file->getClientOriginalName();
        }
        $usuario->idBranch_office = $branchOffice->id;
        $usuario->idSchedule = $schedule->id;
        $usuario->save();

        return Redirect::to('acceso/usuario2')->with(['success' =>  $usuario->Nombres . ' agregado, correctamente!.']);
    }


    public function edit($id)
    {
        $empresa = Empresa::all();
        $user = User::findOrFail($id);
        $m_empresa = BranchOffice::findOrFail($user->idBranch_office);
        return view("acceso.usuario2.edit",["usuario"=>$user, "empresa"=>$empresa, "m_empresa"=>$m_empresa->idEmpresa]);
    }



    public function update(UsuarioFormRequest $request, $id)
    {
        $branchOffice = DB::table('branch_office')->where('idEmpresa', $request->get('empresa'))
            ->where('name', 'solo_admin')
            ->first();
        $schedule = DB::table('schedule')->where('idEmpresa', $request->get('empresa'))
            ->where('name', 'solo_admin')
            ->first();

        $usuario=User::findOrFail($id);
        $usuario->Nombres=$request->get('Nombres');
        $usuario->NumDocumento=$request->get('NumDocumento');
        $usuario->Direccion=$request->get('Direccion');
        $usuario->TelefCel=$request->get('TelefCel');
        $usuario->Correo=$request->get('Correo');
        if ($request->get('password') != ''){
            $usuario->password = bcrypt($request->get('password'));
        }
        if($request->hasFile('foto')){
            $file = $request->file('foto');
            $file->move(public_path().'/Imagen',$file->getClientOriginalName());
            $usuario -> foto=$file->getClientOriginalName();
        }
        $usuario->idBranch_office = $branchOffice->id;
        $usuario->idSchedule = $schedule->id;
        $usuario->update();
        return Redirect::to('acceso/usuario2')->with(['success' =>  $usuario->Nombres . ' modificado, correctamente!.']);
    }


    public function show($id){
        $n_id = substr($id, 1);

        $vuser=DB::table('usuario')
        ->where('IdUsuario','=', $n_id)
        ->first();
        if (isset($vuser->Estado)){
            if($vuser->Estado=='ACTIVO'){
                $estado = "INACTIVO";
            }else{
                $estado = "ACTIVO";
            }
        }

        $usuario=User::findOrFail($n_id);
        $usuario->Estado=$estado;
        $usuario->update();
        return Redirect::to('acceso/usuario2')->with(['success' => 'El estado de ' . $usuario->Nombres . ' fué modificado.']);
    }

    public function destroy(Request $request, $id)
    {
        try {
            if ($request->ajax()) {

                $docu   = User::findOrFail($id);

                if ($docu->delete()) {
                    return response()->json([
                        'success' => true,
                        'message' => '¡Satisfactorio!, Registro eliminado con éxito.',
                    ]);
                } else {
                    return response()->json([
                        'success' => false,
                        'message' => '¡Error!, No se pudo eliminar.',
                    ]);
                }
            }
        } catch (\Exception $e) {
            if ($request->ajax()) {
                return response()->json([
                    'success' => false,
                    'message' => '¡Error!, Este registro tiene enlazado uno o mas registros.',
                ]);
            }
        }
    }
}
