<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\UsuarioFormRequest;
use App\User;
use App\BranchOffice;
use App\Schedule;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;

class Usuario3Controller extends Controller
{
    public function __construct(){
        $this->middleware('auth');
    }
    public function index(Request $request)
    {

        if (auth()->user()->TipoUsuario != "SUPER_ADMIN"){
            Auth::logout();
            return redirect('/')
            ->with('flash','Usted no tiene privilegios para ingresar en la ruta solicitada.');
        }
        if ($request) {
            $query=trim($request->get('searchText'));

            $usuario = DB::table('usuario as u')
            ->select('u.IdUsuario', 'Nombres', 'NumDocumento',
            'Direccion', 'TelefCel', 'Correo', 'foto', 'pagoHora', 'Estado','TipoUsuario')
            ->where('TipoUsuario', 'SUPER_ADMIN')
            ->where(function ($q)  use ($query) {
                $q->orWhere('Nombres', 'LIKE' , '%' . $query . '%')
                ->orWhere('NumDocumento', 'LIKE' , '%' . $query . '%')
                ->orWhere('TipoUsuario', 'LIKE' , '%' . $query . '%')
                ->orWhere('Estado', 'LIKE' , '%' . $query . '%');
            })
            ->paginate(7);

            return view('acceso.super-administrador.index',["usuario"=>$usuario, "searchText"=>$query]);
        }

    }

    public function store(UsuarioFormRequest $request)
    {

        $usuario = new User;
        $usuario->Nombres = $request->get('Nombres');
        $usuario->NumDocumento = $request->get('NumDocumento');
        $usuario->password = bcrypt($request->get('NumDocumento'));
        $usuario->clave = $request->get('NumDocumento');
        $usuario->Direccion = $request->get('Direccion');
        $usuario->TelefCel = $request->get('Telefono');
        $usuario->Correo = $request->get('correo');
        $usuario->Estado = "ACTIVO";
        $usuario->TipoUsuario = 'SUPER_ADMIN';

        if($request->hasFile('foto')){
            $file = $request->file('foto');
            $file->move(public_path().'/Imagen',$file->getClientOriginalName());
            $usuario -> foto=$file->getClientOriginalName();
        }

        $usuario->idBranch_office = 1;
        $usuario->idSchedule = 1;
        $usuario->save();

        return Redirect::to('acceso/super-administrador')->with(['success' =>  $usuario->Nombres . ' agregado, correctamente!.']);
    }


    public function edit($id)
    {
        return view("acceso.super-administrador.edit",["usuario"=>User::findOrFail($id)]);
    }



    public function update(UsuarioFormRequest $request,$id)
    {
        $usuario=User::findOrFail($id);
        $usuario->Nombres=$request->get('Nombres');
        $usuario->NumDocumento=$request->get('NumDocumento');
        $usuario->Direccion=$request->get('Direccion');
        $usuario->TelefCel=$request->get('TelefCel');
        $usuario->Correo=$request->get('Correo');
        // $usuario->TipoUsuario=$request->get('TipoUsuario');
        if ($request->get('password') != ''){
            $usuario->password = bcrypt($request->get('password'));
        }
        if($request->hasFile('foto')){
            $file = $request->file('foto');
            $file->move(public_path().'/Imagen',$file->getClientOriginalName());
            $usuario -> foto=$file->getClientOriginalName();
        }

        $usuario->update();

        return Redirect::to('acceso/super-administrador')->with(['success' =>  $usuario->Nombres . ' modificado, correctamente!.']);
    }

    public function destroy(Request $request, $id)
    {
        try {
            if ($request->ajax()) {

                $docu   = User::findOrFail($id);

                if ($docu->delete()) {
                    return response()->json([
                        'success' => true,
                        'message' => '¡Satisfactorio!, Registro eliminado con éxito.',
                    ]);
                } else {
                    return response()->json([
                        'success' => false,
                        'message' => '¡Error!, No se pudo eliminar.',
                    ]);
                }
            }
        } catch (\Exception $e) {
            if ($request->ajax()) {
                return response()->json([
                    'success' => false,
                    'message' => '¡Error!, Este registro tiene enlazado uno o mas registros.',
                ]);
            }
        }
    }

    public function show($id){
        $n_id = substr($id, 1);

        $vuser=DB::table('usuario')
        ->where('IdUsuario','=', $n_id)
        ->first();
        if (isset($vuser->Estado)){
            if($vuser->Estado=='ACTIVO'){
                $estado = "INACTIVO";
            }else{
                $estado = "ACTIVO";
            }
        }

        $usuario=User::findOrFail($n_id);
        $usuario->Estado=$estado;
        $usuario->update();
        return Redirect::to('acceso/super-administrador')->with(['success' => 'El estado de ' . $usuario->Nombres . ' fué modificado.']);
    }
}
