<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\UsuarioFormRequest;
use App\User;
use App\BranchOffice;
use App\Registro;
use App\Schedule;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;

class UsuarioController extends Controller
{


    public function __construct(){
        $this->middleware('auth');
    }
    public function index(Request $request)
    {

        if (auth()->user()->TipoUsuario =="PERSONAL"){
            Auth::logout();
            return redirect('/')
            ->with('flash','Usted no tiene privilegios para ingresar en la ruta solicitada.');
        }
        if ($request) {
            $query=trim($request->get('searchText'));

            $miEmpresa = DB::table('usuario as u')
            ->join('branch_office as b', 'u.idBranch_office', 'b.id')
            ->where('u.IdUsuario', auth()->user()->IdUsuario)
            ->first();
            $usuario = DB::table('usuario as u')
            ->join('branch_office as b', 'u.idBranch_office', 'b.id')
            ->join('schedule as s', 'u.idSchedule', 's.id')
            ->select('u.IdUsuario', 'Nombres', 'b.name as namebranch_office', 's.name as nameSchedule', 'NumDocumento',
            'Direccion', 'TelefCel', 'Correo', 'foto', 'pagoHora', 'Estado','TipoUsuario')
            ->where('b.idEmpresa', $miEmpresa->idEmpresa)
            ->where(function ($q)  use ($query) {
                $q->orWhere('Nombres', 'LIKE' , '%' . $query . '%')
                ->orWhere('NumDocumento', 'LIKE' , '%' . $query . '%')
                ->orWhere('TipoUsuario', 'LIKE' , '%' . $query . '%')
                ->orWhere('Estado', 'LIKE' , '%' . $query . '%');
            })
            ->paginate(7);

            $branch_office = DB::table('branch_office')
                ->where('name', '!=', 'solo_admin')
                ->where('idEmpresa', $miEmpresa->idEmpresa)->get();
            $schedule = DB::table('schedule')
                ->where('name', '!=', 'solo_admin')
                ->where('idEmpresa', $miEmpresa->idEmpresa)->get();

            return view('acceso.usuario.index',["usuario"=>$usuario, "branch_office"=>$branch_office, "schedule"=>$schedule,"searchText"=>$query]);
        }

    }

    public function store(UsuarioFormRequest $request)
    {

        $miEmpresa = DB::table('usuario as u')
            ->join('branch_office as b', 'u.idBranch_office', 'b.id')
            ->where('u.IdUsuario', auth()->user()->IdUsuario)
            ->first();

        $branchOffice = DB::table('branch_office')->where('idEmpresa', $miEmpresa->idEmpresa)->first();
        $schedule = DB::table('schedule')->where('idEmpresa', $miEmpresa->idEmpresa)->first();

        $usuario = new User;
        $usuario->Nombres = $request->get('Nombres');
        $usuario->NumDocumento = $request->get('NumDocumento');
        $usuario->password = bcrypt($request->get('NumDocumento'));
        $usuario->clave = $request->get('NumDocumento');
        $usuario->Direccion = $request->get('Direccion');
        $usuario->TelefCel = $request->get('Telefono');
        $usuario->Correo = $request->get('correo');
        $usuario->Estado = "ACTIVO";
        $usuario->TipoUsuario = $request->get('TipoUsuario');
        if($request->hasFile('foto')){
            $file = $request->file('foto');
            $file->move(public_path().'/Imagen',$file->getClientOriginalName());
            $usuario -> foto=$file->getClientOriginalName();
        }
        $usuario->pagoHora = $request->get('TipoUsuario') == 'ADMINISTRADOR' ? '0' : $request->get('pagoHora');
        $usuario->idBranch_office = $request->get('TipoUsuario') == 'ADMINISTRADOR' ? $branchOffice->id : $request->get('idBranch_office');
        $usuario->idSchedule = $request->get('TipoUsuario') == 'ADMINISTRADOR' ? $schedule->id : $request->get('idSchedule');
        // $carbon = new \Carbon\Carbon();
        // $date = $carbon->now();
        // $usuario->CreadoEn = $date;
        $usuario->save();

        return Redirect::to('acceso/usuarios')->with(['success' =>  $usuario->Nombres . ' agregado, correctamente!.']);
    }


    public function edit($id)
    {
        $miEmpresa = DB::table('usuario as u')->join('branch_office as b', 'u.idBranch_office', 'b.id')->where('u.IdUsuario', auth()->user()->IdUsuario)
            ->first();
        $branch_office = DB::table('branch_office')->where('name', '!=', 'solo_admin')->where('idEmpresa', $miEmpresa->idEmpresa)->get();
        $schedule = DB::table('schedule')->where('name', '!=', 'solo_admin')->where('idEmpresa', $miEmpresa->idEmpresa)->get();
        $tipo = ['ADMINISTRADOR', 'PERSONAL'];
        return view("acceso.usuario.edit",["usuario"=>User::findOrFail($id), "tipo"=>$tipo, "branch_office"=>$branch_office, "schedule"=>$schedule]);
    }



    public function update(UsuarioFormRequest $request,$id)
    {
        $miEmpresa = DB::table('usuario as u')
            ->join('branch_office as b', 'u.idBranch_office', 'b.id')
            ->where('u.IdUsuario', auth()->user()->IdUsuario)
            ->first();

        $branchOffice = DB::table('branch_office')->where('idEmpresa', $miEmpresa->idEmpresa)->first();
        $schedule = DB::table('schedule')->where('idEmpresa', $miEmpresa->idEmpresa)->first();

        $usuario=User::findOrFail($id);
        $usuario->Nombres=$request->get('Nombres');
        $usuario->NumDocumento=$request->get('NumDocumento');
        $usuario->Direccion=$request->get('Direccion');
        $usuario->TelefCel=$request->get('TelefCel');
        $usuario->Correo=$request->get('Correo');
        $usuario->TipoUsuario=$request->get('TipoUsuario');
        if($request->hasFile('foto')){
            $file = $request->file('foto');
            $file->move(public_path().'/Imagen',$file->getClientOriginalName());
            $usuario -> foto=$file->getClientOriginalName();
        }
        $usuario->pagoHora = $request->get('TipoUsuario') == 'ADMINISTRADOR' ? '0' : $request->get('pagoHora');
        $usuario->idBranch_office = $request->get('TipoUsuario') == 'ADMINISTRADOR' ? $branchOffice->id : $request->get('idBranch_office');
        $usuario->idSchedule = $request->get('TipoUsuario') == 'ADMINISTRADOR' ? $schedule->id : $request->get('idSchedule');
        $usuario->update();
        return Redirect::to('acceso/usuarios')->with(['success' =>  $usuario->Nombres . ' modificado, correctamente!.']);
    }

    public function show($id){
        $n_id = substr($id, 1);

        $vuser=DB::table('usuario')
        ->where('IdUsuario','=', $n_id)
        ->first();
        if (isset($vuser->Estado)){
            if($vuser->Estado=='ACTIVO'){
                $estado = "INACTIVO";
            }else{
                $estado = "ACTIVO";
            }
        }

        $usuario=User::findOrFail($n_id);
        $usuario->Estado=$estado;
        $usuario->update();
        return Redirect::to('acceso/usuarios')->with(['success' => 'El estado de ' . $usuario->Nombres . ' fué modificado.']);
    }

    public static function validation_destroy($id){
        return Registro::where('IdUsuario', $id)->count() == 0 ? true : false;
    }



}
